@@ -2,7 +2,7 @@ import structlog
 import sys
 
 
-def get_logger(name: str) -> structlog.stdlib.BoundLogger:
+def get_logger() -> structlog.stdlib.BoundLogger:
     shared_processors = [
         structlog.stdlib.add_log_level,
         structlog.stdlib.PositionalArgumentsFormatter(),
